@@ -8,6 +8,11 @@ if ( $Config{myarchname} =~ /i386/ ) {
     # Match arch options with the running perl
     if ( my @archs = $Config{ccflags} =~ /-arch ([^ ]+)/g ) {
         $arch = join( '', map { "-arch $_ " } @archs );
+        
+        if ( -e 'MANIFEST.SKIP' ) {
+            # XXX for development, use only one arch to speed up compiles
+            $arch = '-arch x86_64 ';
+        }
     }
     
     # Read OS version
